@@ -9,7 +9,6 @@ package Portal::UserProperties::User;
 use strict;
 use Portal::AppState;
 use Portal::Forms::User;
-use Portal::UserProperties::Objects::Menu;
 use Portal::XML::ConfigParser;
 use Portal::XML::ConfigObject;
 use Portal::Objects::UserPreferenceObject;
@@ -20,11 +19,14 @@ require Exporter;
 @ISA = qw(Portal::AppState Exporter AutoLoader);
 @EXPORT = qw();
 
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 # global variables.
 # modify to represent the commands this state provides.
-my %commands = ( display => "View User Info", editUser => "Edit User Info", changePassword => "Change User Password", preferences => "User Preferences", );
+# the name => value have the following meaning:
+# name is the command this state recognizes.
+# value is the langObj entry to use for the title when processing that command.
+my %commands = ( display => "userInfo", editUser => "EditUserInfo", changePassword => "changePassword", preferences => "userPreferences", );
 
 =head1 NAME
 
@@ -72,7 +74,7 @@ sub new
   # instantiate anything unique to this module
   $self->{commands} = \%commands;
   $self->{state} = "User";
-  
+
   my $arguments = $self->arguments();
   eval "\$self->{userForms} = Portal::Forms::User->new($arguments);";
   if ($@)
@@ -85,7 +87,7 @@ sub new
     $self->error($self->{userForms}->errorMessage);
     return $self;
   }
-  
+
 
   # do validation
   if (!$self->isValid)
@@ -95,6 +97,7 @@ sub new
   }
 
   # do anything else you might need to do.
+  $self->buildUrls;
 
   return $self;
 }
@@ -146,15 +149,7 @@ sub isValid
 sub c_display
 {
   my $self = shift;
-  my $doc = $self->setupCSS();
-  if ($self->error)
-  {
-    $self->prefixError();
-    return undef;
-  }
-
-  # start the page display overall with the menus.
-  $doc = $self->displayMenu(doc => $doc, command => "display");
+  my $doc = $self->prepDoc(template => "menubar+sidemenu-left");
   if ($self->error)
   {
     $self->prefixError();
@@ -168,12 +163,12 @@ sub c_display
     $self->error($self->{userForms}->errorMessage);
     return undef;
   }
-  
+
   # now display the output to the user.
+  $doc->printTag(tag => "<maincontent>", value => $output{body});
+  delete $output{body};
+  # output the rest of the form info.
   $doc->print(%output);
-  
-  # finish off the screen, closing out what the displayMenu() method started.
-  $doc = $self->closeMenu(doc => $doc);
 
   return $doc;
 }
@@ -184,7 +179,7 @@ sub c_display
 sub c_editUser
 {
   my $self = shift;
-  my $doc = $self->setupCSS();
+  my $doc = $self->prepDoc(template => "menubar+sidemenu-left");
   if ($self->error)
   {
     $self->prefixError();
@@ -192,57 +187,41 @@ sub c_editUser
   }
   my $successEditPhrase = $self->langObj->map("successUserEdit");
 
-  my $url = $self->{methods}->createBaseURL(type => "App", linkType => "cgi", appConfigObj => $self->{sessionObj}->{store}->{companyAppObj});
-  if ($self->{methods}->error)
-  {
-    $self->error($self->{methods}->errorMessage);
-    return undef;
-  }
-
-  # start the page display overall with the menus.
-  $doc = $self->displayMenu(doc => $doc, command => "editUser");
-  if ($self->error)
-  {
-    $self->prefixError();
-    return undef;
-  }
+  my $url = $self->url;
 
   # call the Portal::Forms::User module to do the core display, validation and update work
   my @result = $self->{userForms}->editUser(user => $self->{userObj},
       url => $url, app => $self->{app}, state => $self->{state});
-      
+
   if ($self->{userForms}->error)
   {
     $self->error($self->{userForms}->errorMessage);
     return undef;
   }
-  
+
   # now display the output to the user.
   if ($result[0] == 2)
   {
+    $doc->printTag(tag => "<maincontent>", value => $result[1]->{body});
+    delete $result[1]->{body};
+    # output the rest of the form info.
     $doc->print(%{$result[1]});
     $doc->setOnload(code => $result[3]);
   }
   elsif ($result[0] == 1)
   {
-    $self->{methods}->displayMessage(doc => $doc, type => "status", message => $successEditPhrase,
-                                     langObj => $self->{langObj}, break => "below");
+    $doc->printTag(tag => "<maincontent>", value => $self->{methods}->displayMessageStr(doc => $doc, type => "status", message => $successEditPhrase,
+                                     break => "below"));
     if ($self->{methods}->error)
     {
       $self->error($self->{methods}->errorMessage);
       return undef;
     }
-    
+
     # update the session for our userObj.
     $self->{portalSession}->{store}->{userObj} = $result[2];
     $self->{portalSession}->{store}->{changed} = 1;
   }
-  
-  # finish off the screen, closing out what the displayMenu() method started.
-  if ($result[0] != 0)
-  {
-    $doc = $self->closeMenu(doc => $doc);
-  }
 
   return $doc;
 }
@@ -253,7 +232,7 @@ sub c_editUser
 sub c_changePassword
 {
   my $self = shift;
-  my $doc = $self->setupCSS();
+  my $doc = $self->prepDoc(template => "menubar+sidemenu-left");
   if ($self->error)
   {
     $self->prefixError();
@@ -261,53 +240,37 @@ sub c_changePassword
   }
   my $successPasswordPhrase = $self->langObj->map("successPassword");
 
-  my $url = $self->{methods}->createBaseURL(type => "App", linkType => "cgi", appConfigObj => $self->{sessionObj}->{store}->{companyAppObj});
-  if ($self->{methods}->error)
-  {
-    $self->error($self->{methods}->errorMessage);
-    return undef;
-  }
-
-  # start the page display overall with the menus.
-  $doc = $self->displayMenu(doc => $doc, command => "changePassword");
-  if ($self->error)
-  {
-    $self->prefixError();
-    return undef;
-  }
+  my $url = $self->url;
 
   # call the Portal::Forms::User module to do the core display, validation and update work
   my @result = $self->{userForms}->changePassword(user => $self->{userObj},
       url => $url, app => $self->{app}, state => $self->{state});
-      
+
   if ($self->{userForms}->error)
   {
     $self->error($self->{userForms}->errorMessage);
     return undef;
   }
-  
+
   # now display the output to the user.
   if ($result[0] == 2)
   {
+    $doc->printTag(tag => "<maincontent>", value => $result[1]->{body});
+    delete $result[1]->{body};
+    # output the rest of the form info.
     $doc->print(%{$result[1]});
     $doc->setOnload(code => $result[2]);
   }
   elsif ($result[0] == 1)
   {
-    $self->{methods}->displayMessage(doc => $doc, type => "status", message => $successPasswordPhrase,
-                                     langObj => $self->{langObj}, break => "below");
+    $doc->printTag(tag => "<maincontent>", value => $self->{methods}->displayMessageStr(doc => $doc, type => "status", message => $successPasswordPhrase,
+                                     break => "below"));
     if ($self->{methods}->error)
     {
       $self->error($self->{methods}->errorMessage);
       return undef;
     }
   }
-  
-  # finish off the screen, closing out what the displayMenu() method started.
-  if ($result[0] != 0)
-  {
-    $doc = $self->closeMenu(doc => $doc);
-  }
 
   return $doc;
 }
@@ -318,7 +281,7 @@ sub c_changePassword
 sub c_preferences
 {
   my $self = shift;
-  my $doc = $self->setupCSS();
+  my $doc = $self->prepDoc(template => "menubar+sidemenu-left");
   if ($self->error)
   {
     $self->prefixError();
@@ -647,24 +610,13 @@ sub displayUserPreferences
     }
   }
 
-  my $url = $self->{methods}->createBaseURL(type => "App", linkType => "cgi", appConfigObj => $self->{sessionObj}->{store}->{companyAppObj});
-  if ($self->{methods}->error)
-  {
-    $self->error($self->{methods}->errorMessage);
-    return undef;
-  }
-
-  $doc = $self->displayMenu(doc => $doc, command => "preferences");
-  if ($self->error)
-  {
-    $self->prefixError();
-    return $doc;
-  }
+  my $url = $self->url;
+  my $output = "";
 
   if ($error)
   {
-    $self->{methods}->displayMessage(doc => $doc, type => "error", message => $error,
-                                     langObj => $self->{langObj}, break => "below");
+    $output .= $self->{methods}->displayMessageStr(doc => $doc, type => "error", message => $error,
+                                     break => "below");
     if ($self->{methods}->error)
     {
       $self->error($self->{methods}->errorMessage);
@@ -673,8 +625,8 @@ sub displayUserPreferences
   }
   if ($status)
   {
-    $self->{methods}->displayMessage(doc => $doc, type => "status", message => $status,
-                                     langObj => $self->{langObj}, break => "below");
+    $output .= $self->{methods}->displayMessageStr(doc => $doc, type => "status", message => $status,
+                                     break => "below");
     if ($self->{methods}->error)
     {
       $self->error($self->{methods}->errorMessage);
@@ -683,7 +635,7 @@ sub displayUserPreferences
   }
 
   # generate the form to let them edit their Portal Preferences.
-  $doc->print(<<"END_OF_CODE");
+  $output .= <<"END_OF_CODE";
 $editPhrase $userPreferencesPhrase
 <br>
 <form name="preferences" method="post" action="$url">
@@ -712,9 +664,9 @@ END_OF_CODE
     foreach my $option (@systemColorSchemes, @userColorSchemes)
     {
       my $selected = ($preferences{Global}{colorScheme} eq "$option" ? " selected" : "");
-      $doc->print("          <option value=\"$option\"$selected>$option\n");
+      $output .= "          <option value=\"$option\"$selected>$option\n";
     }
-  $doc->print(<<"END_OF_CODE");
+  $output .= <<"END_OF_CODE";
         </select>
       </td>
     </tr>
@@ -726,9 +678,9 @@ END_OF_CODE
     foreach my $option ("1", "0")
     {
       my $selected = ($preferences{Desktop}{dynamicContent} eq "$option" ? " selected" : "");
-      $doc->print("          <option value=\"$option\"$selected>" . ($option ? "true" : "false") . "\n");
+      $output .= "          <option value=\"$option\"$selected>" . ($option ? "true" : "false") . "\n";
     }
-  $doc->print(<<"END_OF_CODE");
+  $output .= <<"END_OF_CODE";
         </select>
       </td>
     </tr>
@@ -743,9 +695,9 @@ END_OF_CODE
     foreach my $option ("0", "1")
     {
       my $selected = ($preferences{Desktop}{frameBorder} eq "$option" ? " selected" : "");
-      $doc->print("          <option value=\"$option\"$selected>$option\n");
+      $output .= "          <option value=\"$option\"$selected>$option\n";
     }
-  $doc->print(<<"END_OF_CODE");
+  $output .= <<"END_OF_CODE";
         </select>
       </td>
     </tr>
@@ -757,9 +709,9 @@ END_OF_CODE
     foreach my $option ("auto", "yes", "no")
     {
       my $selected = ($preferences{Desktop}{frameScrolling} eq "$option" ? " selected" : "");
-      $doc->print("          <option value=\"$option\"$selected>$option\n");
+      $output .= "          <option value=\"$option\"$selected>$option\n";
     }
-  $doc->print(<<"END_OF_CODE");
+  $output .= <<"END_OF_CODE";
         </select>
       </td>
     </tr>
@@ -779,84 +731,11 @@ END_OF_CODE
 </table>
 END_OF_CODE
 
-  return $doc;
-}
-
-sub displayMenu
-{
-  my $self = shift;
-  my %args = ( doc => undef, command => "", @_ );
-  my $doc = $args{doc};
-  my $command = $args{command};
-
-  # create the help JS function.
-  $doc = $self->{methods}->displayJSHelper(doc => $doc, type => "help", langObj => $self->{langObj});
-  if ($self->{methods}->error)
-  {
-    $self->error($self->{methods}->errorMessage);
-    return undef;
-  }
-
-  # create the validateClose JS function.
-  $doc = $self->{methods}->displayJSHelper(doc => $doc, type => "closeApp", langObj => $self->{langObj});
-  if ($self->{methods}->error)
-  {
-    $self->error($self->{methods}->errorMessage);
-    return undef;
-  }
-
-  my $menuObj = Portal::UserProperties::Objects::Menu->new(methods => $self->{methods},
-                sessionObj => $self->{sessionObj}, langObj => $self->{langObj}, userObj => $self->{userObj},
-                portalSession => $self->{portalSession});
-  if ($menuObj->error)
-  {
-    $self->error($menuObj->errorMessage);
-    return undef;
-  }
-
-  my $menuString = $menuObj->print(location => "menubar", state => $self->{state}, command => $command, doc => $doc);
-  if ($menuObj->error)
-  {
-    $self->error($menuObj->errorMessage);
-    return undef;
-  }
-
-  my $sidemenuString = $menuObj->print(location => "sidemenu", state => $self->{state}, command => $command, doc => $doc);
-  if ($menuObj->error)
-  {
-    $self->error($menuObj->errorMessage);
-    return undef;
-  }
-
-  $doc->setFocus("body");
-  $doc->print(<<"END_OF_CODE");
-<center>
-$menuString
-<br>
-<table border="0" cellspacing="0" cellpadding="2" width="100%">
-  <tr>
-    <td width="25%" valign="top">$sidemenuString</td>
-    <td width="75%" align="center">
-END_OF_CODE
+  $doc->printTag(tag => "<maincontent>", value => $output);
 
   return $doc;
 }
 
-sub closeMenu
-{
-  my $self = shift;
-  my %args = ( doc => undef, @_ );
-  my $doc = $args{doc};
-  
-  $doc->print(<<"END_OF_FORM");
-    </td>
-  </tr>
-</table>
-END_OF_FORM
-
-  return $doc;  
-}
-
 1;
 __END__
 
